import{j as e}from"./@tanstack-CEbkxrhX.js";import{B as r,av as i}from"./index-BawkpTlr.js";import{I as a}from"./Infobox-C7bf70VS.js";import{H as o}from"./Helpbox-DW21i5LD.js";import{V as s,g as l}from"./Commands-CTlhyic5.js";import"./@radix-C9DBgJhe.js";import"./@react-router-DYovave8.js";import"./@reactflow-DYIyhCfd.js";import"./help-B8rqCvqn.js";import"./play-circle-DK5QMJyp.js";import"./CodeSnippet-WEzpO0az.js";import"./copy-BRhQz3j-.js";const c=[{command:`zenml secret create SECRET_NAME --key1=value1 --key2=value2 --key3=value3 ...
            

# Another option is to use the '--values' option and provide key-value pairs in either JSON or YAML format.
zenml secret create SECRET_NAME --values '{"key1":"value2","key2":"value2","key3":"value3"}'`,description:"Create a secret"},{command:"zenml secret list",description:"List all the available secrets"},{command:"zenml secret get SECRET_NAME",description:"Get the key-value pairs for a particular secret"},{command:"zenml secret delete SECRET_NAME",description:"Delete a secret that you have previously registered"}],m="/assets/secrets-video-OBJ6irhH.svg";function d(){return e.jsx(a,{children:e.jsxs("div",{className:"flex w-full flex-wrap items-center gap-x-2 gap-y-0.5 text-text-md",children:[e.jsx("p",{className:"font-semibold",children:"We are creating a new Secrets experience"}),e.jsx("p",{children:"In the meanwhile you can use the CLI to add and manage your secrets."})]})})}function u(){const t="https://zenml.portal.trainn.co/share/R0A37qU8LVfcvPi6wxdhaQ/embed?autoplay=false";return e.jsxs(r,{className:"flex flex-col-reverse items-stretch overflow-hidden lg:flex-row",children:[e.jsxs("div",{className:"w-full p-7 lg:w-2/3",children:[e.jsx("h2",{className:"text-display-xs font-semibold",children:"Learn More about Secrets"}),e.jsx("p",{className:"mt-2 text-text-lg text-theme-text-secondary",children:"Learn about using ZenML Secrets for a secure, centralized management of your pipeline secrets and configurations."}),e.jsx(s,{videoLink:t,buttonText:"Watch the Starter Guide (1 min)"})]}),e.jsx("div",{className:"flex w-full items-center justify-center bg-primary-50 lg:w-1/3",children:e.jsx(s,{fallbackImage:e.jsx("img",{src:m,alt:"Purple squares with text indicating a starter guide for secrets",className:"h-full w-full"}),videoLink:t,isButton:!1})})]})}function x(){return e.jsxs("section",{className:"space-y-5 pl-8 pr-5",children:[e.jsx(a,{className:"text-text-md",intent:"neutral",children:"A ZenML Secret is a collection or grouping of key-value pairs stored by the ZenML secrets store. ZenML Secrets are identified by a unique name which allows you to fetch or reference them in your pipelines and stacks."}),c.map((t,n)=>e.jsx(e.Fragment,{children:l(t)},n)),e.jsx(o,{text:"Check all the commands and find more about Secrets in our Docs",link:"https://docs.zenml.io/getting-started/deploying-zenml/manage-the-deployed-services/secret-management"})]})}function E(){return e.jsxs(r,{className:"space-y-4 p-5",children:[e.jsx("h1",{className:"text-text-xl font-semibold",children:"Secrets"}),e.jsx(d,{}),e.jsx(u,{}),e.jsxs("div",{className:"flex items-center gap-2",children:[e.jsx(i,{}),"Administering your Secrets"]}),e.jsx(x,{})]})}export{E as default};
